# AeroCaps
Toolkit for design of Class-A, parametric design of aerodynamic surfaces

## Installation

For installation of `aerocaps` using the latest stable release, use

```shell
pip install aerocaps
```

To install the bleeding-edge version, use

```shell
git clone https://github.com/mlau154/aerocaps.git
```
